BOOST_PP_VARIADIC_TO_SEQ

The BOOST_PP_VARIADIC_TO_SEQ variadic macro converts a variadic data to a seq.

#### Usage

BOOST_PP_VARIADIC_TO_SEQ(...) (v)

#### Arguments

...
  The variadic data to be converted.

#### Requirements

Header: <boost/preprocessor/variadic/to_seq.hpp>

#### Sample Code

    #include <boost/preprocessor/variadic/to_seq.hpp>

    BOOST_PP_VARIADIC_TO_SEQ(a, b, c) // expands to (a)(b)(c)

© Copyright Edward Diener 2011

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)